@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2015-2023, Intel Corporation
+* Copyright (c) 2015-2026, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -403,7 +403,10 @@ typedef enum _MEDIA_EVENT
     EVENT_HWS_NATIVE_FENCE_SYNC_BB_ADDED,          //! event for HWS sync cmd resource added
     EVENT_HWS_NATIVE_FENCE_SIGNAL,                 //! event for HWS native fence signal
     EVENT_HWS_NATIVE_FENCE_WAIT,                   //! event for HWS native fence wait for sync
-    EVENT_HWS_NATIVE_FENCE_CMD_FLUSH               //! event for HWS sync cmd flush
+    EVENT_HWS_NATIVE_FENCE_CMD_FLUSH,              //! event for HWS sync cmd flush
+    EVENT_HWS_NATIVE_FENCE_ADD_TO_ARRAY_CMD,       //! event for Hws Native Fence Add To Array Cmd
+    EVENT_HWS_NATIVE_FENCE_ADD_TO_QUEUE_API,       //! event for Hws Native Fence Add To Queue Api
+    EVENT_HWS_NATIVE_FENCE_12_WAIT                 //! event for Hws Native Fence 12 Wait
 } MEDIA_EVENT;
 
 typedef enum _MEDIA_EVENT_TYPE
@@ -662,6 +665,7 @@ typedef enum _MT_LOG_ID
     MT_CP_FUNC_FAIL,
     MT_CP_CENC_STATUS_CHECK,
     MT_CP_CENC_DECODE_CREATE,
+    MT_CP_CMD_QUEUE_INIT,
     MT_CP_MHW_ID_BASE = 0x01004000,
     MT_CP_MHW_INTERFACE_CREATE_FAIL,
     MT_CP_MHW_ALLOCATION_FAIL,
