@@ -129,7 +129,6 @@
 #define CODECHAL_ENCODE_HEVC_NUM_MAX_VDENC_L0_REF_G10  3 // multiref, hevc vdenc
 #define CODECHAL_ENCODE_HEVC_NUM_MAX_VDENC_L1_REF_G10  3 // multiref, hevc vdenc
 
-#define CODECHAL_VDENC_HEVC_BRC_HISTORY_BUF_SIZE             964
 #define CODECHAL_VDENC_HEVC_BRC_DEBUG_BUF_SIZE               0x1000 // 0x1000 = 4096
 #define CODECHAL_VDENC_HEVC_BRC_HUC_STATUS_ERROR_MASK        (1<<30)
 #define CODECHAL_VDENC_HEVC_BRC_HUC_STATUS_ARITHMETIC_OVERFLOW_ERROR_MASK   (1<<29)
@@ -1096,7 +1095,7 @@ public:
     //!
     virtual MOS_STATUS SubmitCommandBuffer(
         PMOS_COMMAND_BUFFER cmdBuffer,
-        bool                nullRendering);
+        bool                bNullRendering);
 
     //!
     //! \brief    Help function to verify command buffer size
@@ -1609,7 +1608,17 @@ public:
     //!
     //! \return   void
     //!
-    virtual void SetHcpReconSurfaceParams(MHW_VDBOX_SURFACE_PARAMS& reconSurfaceParams);
+    virtual void SetHcpReconSurfaceParams(MHW_VDBOX_SURFACE_PARAMS &reconSurfaceParams);
+
+    //!
+    //! \brief    Set HCP_SURFACE_PARAMS for reference picture
+    //!
+    //! \param    [in, out] refSurfaceParams
+    //!           HCP_SURFACE_PARAMS for reference picture
+    //!
+    //! \return   void
+    //!
+    virtual void SetHcpRefSurfaceParams(MHW_VDBOX_SURFACE_PARAMS &refSurfaceParams);
 
     //!
     //! \brief    Set HCP_PIPE_BUF_ADDR parameters
