@@ -1,27 +1,23 @@
 /*
+* Copyright (c) 2018-2022, Intel Corporation
 *
-* Copyright (c) Intel Corporation 2018.
+* Permission is hereby granted, free of charge, to any person obtaining a
+* copy of this software and associated documentation files (the "Software"),
+* to deal in the Software without restriction, including without limitation
+* the rights to use, copy, modify, merge, publish, distribute, sublicense,
+* and/or sell copies of the Software, and to permit persons to whom the
+* Software is furnished to do so, subject to the following conditions:
 *
-* INTEL MAKES NO WARRANTY OF ANY KIND REGARDING THE CODE.  THIS CODE IS
-* LICENSED ON AN "AS IS" BASIS AND INTEL WILL NOT PROVIDE ANY SUPPORT,
-* ASSISTANCE, INSTALLATION, TRAINING OR OTHER SERVICES.  INTEL DOES NOT
-* PROVIDE ANY UPDATES, ENHANCEMENTS OR EXTENSIONS.  INTEL SPECIFICALLY
-* DISCLAIMS ANY WARRANTY OF MERCHANTABILITY, NONINFRINGEMENT, FITNESS FOR ANY
-* PARTICULAR PURPOSE, OR ANY OTHER WARRANTY.  Intel disclaims all liability,
-* including liability for infringement of any proprietary rights, relating to
-* use of the code. No license, express or implied, by estoppel or otherwise,
-* to any intellectual property rights is granted herein.
-*
-*
-* File Name  : vphal_render_16alignment.h
-*
-* Abstract   : Video surface 16 bytes alignment definitions for Video Processing
-*
-* Environment: Linux
-*
-* Notes      : This module contains video surface 16 bytes alignment definitions
-*              for VPHAL
+* The above copyright notice and this permission notice shall be included
+* in all copies or substantial portions of the Software.
 *
+* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+* OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
+* THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
+* OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
+* ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
+* OTHER DEALINGS IN THE SOFTWARE.
 */
 //!
 //! \file     vphal_render_16alignment.h
@@ -32,7 +28,7 @@
 #define __VPHAL_RENDER_16ALIGNMENT_H__
 
 #include "mos_os.h"
-#include "renderhal.h"
+#include "renderhal_legacy.h"
 #include "vphal_render_common.h"
 
 // Static Data for Gen9 16ALIGN kernel
