@@ -19,16 +19,14 @@
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 */
-
 #include "MDF_FC_common_genx.h"
 
-_GENX_MAIN_ void Y410_444Scale16_Buf_3(
+_GENX_MAIN_ void Y210_444Scale16_Buf_3(
     CURBE_INPUT_OUTPUT,
     GLOBAL_BUFFER_INPUT_OUTPUT)
 {
-#define Y410_SUPPORT
+
 #define BUFFER_3
-#include "PA_Scale_Buf.h"
+#include "Y210_Scale_Buf.h"
 #undef BUFFER_3
-#undef Y410_SUPPORT
 }
\ No newline at end of file
