@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2020-2021, Intel Corporation
+* Copyright (c) 2020-2023, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -52,27 +52,6 @@ MOS_STATUS VpScalabilityMultiPipe::Destroy()
 
     SCALABILITY_CHK_STATUS_RETURN(VpScalabilityMultiPipeNext::Destroy());
 
-    if (m_veInterface)
-    {
-        if (m_veInterface->pfnVEDestroy)
-        {
-            m_veInterface->pfnVEDestroy(m_veInterface);
-        }
-        MOS_FreeMemAndSetNull(m_veInterface);
-    }
-    else
-    {
-        if (!m_osInterface->apoMosEnabled)
-        {
-            // For VE not enabled/supported case, such as vp vebox on some platform, m_veInterface is nullptr.
-            // MOS_STATUS_SUCCESS should be returned for such case.
-            if (MOS_VE_SUPPORTED(m_osInterface))
-            {
-                SCALABILITY_CHK_NULL_RETURN(m_veInterface);
-            }
-        }
-    }
-
     return MOS_STATUS_SUCCESS;
 }
 
@@ -163,6 +142,8 @@ MOS_STATUS VpScalabilityMultiPipe::Initialize(const MediaScalabilityOption &opti
 //!
 //! \param    [in] semaMem
 //!           Reource of Hw semphore
+//! \param    [in] offset
+//!           offset of semMem
 //! \param    [in] semaData
 //!           Data of Hw semphore
 //! \param    [in] opCode
@@ -175,6 +156,7 @@ MOS_STATUS VpScalabilityMultiPipe::Initialize(const MediaScalabilityOption &opti
 //!
 MOS_STATUS VpScalabilityMultiPipe::SendHwSemaphoreWaitCmd(
     PMOS_RESOURCE                             semaMem,
+    uint32_t                                  offset,
     uint32_t                                  semaData,
     MHW_COMMON_MI_SEMAPHORE_COMPARE_OPERATION opCode,
     PMOS_COMMAND_BUFFER                       cmdBuffer)
@@ -195,6 +177,7 @@ MOS_STATUS VpScalabilityMultiPipe::SendHwSemaphoreWaitCmd(
         auto &params             = m_miItf->MHW_GETPAR_F(MI_SEMAPHORE_WAIT)();
         params                   = {};
         params.presSemaphoreMem = semaMem;
+        params.dwResourceOffset = offset;
         params.bPollingWaitMode = true;
         params.dwSemaphoreData  = semaData;
         params.CompareOperation = (mhw::mi::MHW_COMMON_MI_SEMAPHORE_COMPARE_OPERATION) opCode;
@@ -204,6 +187,7 @@ MOS_STATUS VpScalabilityMultiPipe::SendHwSemaphoreWaitCmd(
     {
         MOS_ZeroMemory((&miSemaphoreWaitParams), sizeof(miSemaphoreWaitParams));
         miSemaphoreWaitParams.presSemaphoreMem = semaMem;
+        miSemaphoreWaitParams.dwResourceOffset = offset;
         miSemaphoreWaitParams.bPollingWaitMode = true;
         miSemaphoreWaitParams.dwSemaphoreData  = semaData;
         miSemaphoreWaitParams.CompareOperation = opCode;
@@ -220,6 +204,8 @@ finish:
 //!
 //! \param    [in] resource
 //!           Reource used in mi atomic dword cmd
+//! \param    [in] offset
+//!           offset of resource
 //! \param    [in] immData
 //!           Immediate data
 //! \param    [in] opCode
@@ -232,6 +218,7 @@ finish:
 //!
 MOS_STATUS VpScalabilityMultiPipe::SendMiAtomicDwordCmd(
     PMOS_RESOURCE               resource,
+    uint32_t                    offset,
     uint32_t                    immData,
     MHW_COMMON_MI_ATOMIC_OPCODE opCode,
     PMOS_COMMAND_BUFFER         cmdBuffer)
@@ -252,6 +239,7 @@ MOS_STATUS VpScalabilityMultiPipe::SendMiAtomicDwordCmd(
         auto &params             = m_miItf->MHW_GETPAR_F(MI_ATOMIC)();
         params                   = {};
         params.pOsResource       = resource;
+        params.dwResourceOffset  = offset;
         params.dwDataSize        = sizeof(uint32_t);
         params.Operation         = (mhw::mi::MHW_COMMON_MI_ATOMIC_OPCODE) opCode;
         params.bInlineData       = true;
@@ -262,6 +250,7 @@ MOS_STATUS VpScalabilityMultiPipe::SendMiAtomicDwordCmd(
     {
         MOS_ZeroMemory((&atomicParams), sizeof(atomicParams));
         atomicParams.pOsResource       = resource;
+        atomicParams.dwResourceOffset  = offset;
         atomicParams.dwDataSize        = sizeof(uint32_t);
         atomicParams.Operation         = opCode;
         atomicParams.bInlineData       = true;
@@ -311,7 +300,7 @@ MOS_STATUS VpScalabilityMultiPipe::AddMiFlushDwCmd(
             parFlush.pOsResource = semaMem;
             parFlush.dwDataDW1   = semaData + 1;
         }
-        m_miItf->MHW_ADDCMD_F(MI_FLUSH_DW)(cmdBuffer);
+        SCALABILITY_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_FLUSH_DW)(cmdBuffer));
     }
     else
     {
@@ -335,6 +324,8 @@ MOS_STATUS VpScalabilityMultiPipe::AddMiFlushDwCmd(
 //!
 //! \param    [in] resource
 //!           Reource used in mi store dat dword cmd
+//! \param    [in] offset
+//!           offset of resource
 //! \param    [in,out] cmdBuffer
 //!           command buffer
 //!
@@ -343,6 +334,7 @@ MOS_STATUS VpScalabilityMultiPipe::AddMiFlushDwCmd(
 //!
 MOS_STATUS VpScalabilityMultiPipe::AddMiStoreDataImmCmd(
     PMOS_RESOURCE               resource,
+    uint32_t                    offset,
     PMOS_COMMAND_BUFFER         cmdBuffer)
 {
     VP_FUNC_CALL();
@@ -361,7 +353,7 @@ MOS_STATUS VpScalabilityMultiPipe::AddMiStoreDataImmCmd(
         auto &params             = m_miItf->MHW_GETPAR_F(MI_STORE_DATA_IMM)();
         params                   = {};
         params.pOsResource       = resource;
-        params.dwResourceOffset  = 0;
+        params.dwResourceOffset  = offset;
         params.dwValue           = 0;
         eStatus                  = m_miItf->MHW_ADDCMD_F(MI_STORE_DATA_IMM)(cmdBuffer);
     }
@@ -369,7 +361,7 @@ MOS_STATUS VpScalabilityMultiPipe::AddMiStoreDataImmCmd(
     {
         MHW_MI_STORE_DATA_PARAMS dataParams = {};
         dataParams.pOsResource      = resource;
-        dataParams.dwResourceOffset = 0;
+        dataParams.dwResourceOffset = offset;
         dataParams.dwValue          = 0;
 
         // Reset current pipe semaphore
