@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2019-2021, Intel Corporation
+* Copyright (c) 2019-2024, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -32,6 +32,7 @@ namespace decode {
 
     DecodeStatusReport::DecodeStatusReport(
         DecodeAllocator* allocator, bool enableRcs, PMOS_INTERFACE osInterface):
+        MediaStatusReport(osInterface),
         m_enableRcs(enableRcs),
         m_allocator(allocator),
         m_osInterface(osInterface)
@@ -48,6 +49,7 @@ namespace decode {
     {
         DECODE_FUNC_CALL();
 
+        SetSizeForStatusBuf();
         // Allocate status buffer which includes decode status and completed count
         uint32_t bufferSize = m_statusBufSizeMfx * m_statusNum + m_completedCountSize;
         m_statusBufMfx = m_allocator->AllocateBuffer(
@@ -118,6 +120,25 @@ namespace decode {
             m_statusReportData[submitIndex].frameType            = inputParameters->pictureCodingType;
             m_statusReportData[submitIndex].secondField          = inputParameters->isSecondField;
             m_statusReportData[submitIndex].currFgOutputPicRes   = inputParameters->fgOutputPicRes;
+            m_statusReportData[submitIndex].streamSize           = inputParameters->streamSize;
+
+            if (inputParameters->streamOutBufRes != nullptr)  
+            {  
+                m_statusReportData[submitIndex].streamOutBufRes = *(inputParameters->streamOutBufRes);  
+            }  
+            else
+            {
+                m_statusReportData[submitIndex].streamOutBufRes = {0};
+            }
+
+            if (inputParameters->streamInBufRes != nullptr)  
+            {  
+                m_statusReportData[submitIndex].streamInBufRes = *(inputParameters->streamInBufRes);
+            }  
+            else
+            {
+                m_statusReportData[submitIndex].streamInBufRes = {0};
+            }
 #endif
         }
 
@@ -182,6 +203,13 @@ namespace decode {
         // The frame is completed, notify the observers
         if (statusReportData->codecStatus == CODECHAL_STATUS_SUCCESSFUL)
         {
+#if (_DEBUG || _RELEASE_INTERNAL)
+            if (m_enableVdboxIdReport)
+            {
+                DECODE_CHK_NULL(decodeStatusMfx);
+                ParseVdboxIdsFromBuf(decodeStatusMfx->m_mmioCsEngineIdReg);
+            }
+#endif
             NotifyObservers(decodeStatusMfx, decodeStatusRcs, statusReportData);
         }
 
@@ -203,6 +231,12 @@ namespace decode {
         return MOS_STATUS_SUCCESS;
     }
 
+    void DecodeStatusReport::SetSizeForStatusBuf()
+    {
+        m_statusBufSizeMfx = MOS_ALIGN_CEIL(sizeof(DecodeStatusMfx), sizeof(uint64_t));
+        m_statusBufSizeRcs = MOS_ALIGN_CEIL(sizeof(DecodeStatusRcs), sizeof(uint64_t));
+    }
+
     void DecodeStatusReport::SetOffsetsForStatusBuf()
     {
         const uint32_t mfxStatusOffset = 0;
@@ -218,14 +252,15 @@ namespace decode {
         m_statusBufAddr[CsEngineIdOffset_5].offset   = mfxStatusOffset + CODECHAL_OFFSETOF(DecodeStatusMfx, m_mmioCsEngineIdReg[5]);
         m_statusBufAddr[CsEngineIdOffset_6].offset   = mfxStatusOffset + CODECHAL_OFFSETOF(DecodeStatusMfx, m_mmioCsEngineIdReg[6]);
         m_statusBufAddr[CsEngineIdOffset_7].offset   = mfxStatusOffset + CODECHAL_OFFSETOF(DecodeStatusMfx, m_mmioCsEngineIdReg[7]);
-        m_statusBufAddr[HucErrorStatus2Mask].offset  = mfxStatusOffset + CODECHAL_OFFSETOF(DecodeStatusMfx, m_hucErrorStatus2);
-        m_statusBufAddr[HucErrorStatus2Reg].offset   = mfxStatusOffset + CODECHAL_OFFSETOF(DecodeStatusMfx, m_hucErrorStatus2) + sizeof(uint32_t);
-        m_statusBufAddr[HucErrorStatusMask].offset   = mfxStatusOffset + CODECHAL_OFFSETOF(DecodeStatusMfx, m_hucErrorStatus);
-        m_statusBufAddr[HucErrorStatusReg].offset    = mfxStatusOffset + CODECHAL_OFFSETOF(DecodeStatusMfx, m_hucErrorStatus) + sizeof(uint32_t);
+    m_statusBufAddr[HucErrorStatus2Mask].offset  = mfxStatusOffset + CODECHAL_OFFSETOF(DecodeStatusMfx, m_hucErrorStatus2);
+    m_statusBufAddr[HucErrorStatus2Reg].offset   = mfxStatusOffset + CODECHAL_OFFSETOF(DecodeStatusMfx, m_hucErrorStatus2) + sizeof(uint32_t);
+    m_statusBufAddr[HucErrorStatusMask].offset   = mfxStatusOffset + CODECHAL_OFFSETOF(DecodeStatusMfx, m_hucErrorStatus);
+    m_statusBufAddr[HucErrorStatusReg].offset    = mfxStatusOffset + CODECHAL_OFFSETOF(DecodeStatusMfx, m_hucErrorStatus) + sizeof(uint32_t);
+    m_statusBufAddr[statusReportCmdCounter].offset = mfxStatusOffset + CODECHAL_OFFSETOF(DecodeStatusMfx, m_mmioCmdCounterReg);
 
-        const uint32_t rcsStatusOffset = 0;
-        m_statusBufAddr[statusReportRcs].offset      = rcsStatusOffset + CODECHAL_OFFSETOF(DecodeStatusRcs, status);
-    }
+    const uint32_t rcsStatusOffset = 0;
+    m_statusBufAddr[statusReportRcs].offset      = rcsStatusOffset + CODECHAL_OFFSETOF(DecodeStatusRcs, status);
+}
 
     MOS_STATUS DecodeStatusReport::UpdateCodecStatus(
         DecodeStatusReportData* statusReportData,
@@ -242,7 +277,7 @@ namespace decode {
         }
         else if (!completed)
         {
-            statusReportData->codecStatus = CODECHAL_STATUS_ERROR;
+            statusReportData->codecStatus = CODECHAL_STATUS_RESET;
             DECODE_ASSERTMESSAGE("Media reset may have occured.");
         }
         else
@@ -266,11 +301,32 @@ namespace decode {
         return m_statusReportData[index];
     }
 
+#if (_DEBUG || _RELEASE_INTERNAL)
+    MOS_STATUS DecodeStatusReport::ReportUsedVdboxIds()
+    {
+        if (m_enableVdboxIdReport)
+        {
+            DECODE_CHK_NULL(m_dataStatusMfx);
+            DECODE_CHK_NULL(m_completedCount);
+            uint32_t completedCount = *m_completedCount;
+            for (uint32_t num = m_reportedCount; num < completedCount; num++)
+            {
+                const DecodeStatusMfx& status = GetMfxStatus(num);
+                ParseVdboxIdsFromBuf(status.m_mmioCsEngineIdReg);
+            }
+            MediaStatusReport::ReportUsedVdboxIds();
+        }
+        return MOS_STATUS_SUCCESS;
+    }
+#endif
+
     MOS_STATUS DecodeStatusReport::Destroy()
     {
         DECODE_FUNC_CALL();
-
-        if (m_statusBufMfx != nullptr)
+#if (_DEBUG || _RELEASE_INTERNAL)
+        ReportUsedVdboxIds();
+#endif
+        if (m_allocator != nullptr && m_statusBufMfx != nullptr)
         {
             m_allocator->UnLock(m_statusBufMfx);
             m_allocator->Destroy(m_statusBufMfx);
@@ -278,7 +334,7 @@ namespace decode {
             m_completedCountBuf = nullptr;
         }
 
-        if (m_statusBufRcs != nullptr)
+        if (m_allocator != nullptr && m_statusBufRcs != nullptr)
         {
             m_allocator->UnLock(m_statusBufRcs);
             m_allocator->Destroy(m_statusBufRcs);
