@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2018, Intel Corporation
+* Copyright (c) 2023, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -37,13 +37,11 @@ namespace encode
 {
 HevcBasicFeature::~HevcBasicFeature()
 {
-#ifdef _ENCODE_RESERVED
-    if (m_rsvdState)
+    if (m_422State)
     {
-        MOS_Delete(m_rsvdState);
-        m_rsvdState = nullptr;
+        MOS_Delete(m_422State);
+        m_422State = nullptr;
     }
-#endif
 }
 
 MOS_STATUS HevcBasicFeature::Init(void *setting)
@@ -109,9 +107,7 @@ MOS_STATUS HevcBasicFeature::Init(void *setting)
 #endif  // _DEBUG || _RELEASE_INTERNAL
     m_hevcRDOQPerfDisabled = outValue.Get<bool>();
 
-#ifdef _ENCODE_RESERVED
-    ENCODE_CHK_STATUS_RETURN(InitRsvdState());
-#endif
+    ENCODE_CHK_STATUS_RETURN(Init422State());
 
     return MOS_STATUS_SUCCESS;
 }
@@ -138,12 +134,11 @@ MOS_STATUS HevcBasicFeature::Update(void *params)
     m_NumNalUnits   = encodeParams->uiNumNalUnits;
     m_bEnableSubPelMode = encodeParams->bEnableSubPelMode;
     m_SubPelMode        = encodeParams->SubPelMode;
-#ifdef _ENCODE_RESERVED
-    if (m_rsvdState && m_rsvdState->GetFeatureRsvdFlag())
+
+    if (m_422State && m_422State->GetFeature422Flag())
     {
-        ENCODE_CHK_STATUS_RETURN(m_rsvdState->UpdateRsvdFormat(m_hevcSeqParams, m_outputChromaFormat, m_reconSurface.Format, m_is10Bit));
+        ENCODE_CHK_STATUS_RETURN(m_422State->Update422Format(m_hevcSeqParams, m_outputChromaFormat, m_reconSurface.Format, m_is10Bit));
     }
-#endif
 
     if (encodeParams->bAcceleratorHeaderPackingCaps)
     {
@@ -257,6 +252,122 @@ MOS_STATUS HevcBasicFeature::CalcLCUMaxCodingSize()
     return MOS_STATUS_SUCCESS;
 }
 
+void HevcBasicFeature::CreateFlatScalingList()
+{
+    ENCODE_FUNC_CALL();
+
+    for (auto i = 0; i < 6; i++)
+    {
+        memset(&(m_hevcIqMatrixParams->ucScalingLists0[i][0]),
+            0x10,
+            sizeof(m_hevcIqMatrixParams->ucScalingLists0[i]));
+
+        memset(&(m_hevcIqMatrixParams->ucScalingLists1[i][0]),
+            0x10,
+            sizeof(m_hevcIqMatrixParams->ucScalingLists1[i]));
+
+        memset(&(m_hevcIqMatrixParams->ucScalingLists2[i][0]),
+            0x10,
+            sizeof(m_hevcIqMatrixParams->ucScalingLists2[i]));
+    }
+
+    memset(&(m_hevcIqMatrixParams->ucScalingLists3[0][0]),
+        0x10,
+        sizeof(m_hevcIqMatrixParams->ucScalingLists3[0]));
+
+    memset(&(m_hevcIqMatrixParams->ucScalingLists3[1][0]),
+        0x10,
+        sizeof(m_hevcIqMatrixParams->ucScalingLists3[1]));
+
+    memset(&(m_hevcIqMatrixParams->ucScalingListDCCoefSizeID2[0]),
+        0x10,
+        sizeof(m_hevcIqMatrixParams->ucScalingListDCCoefSizeID2));
+
+    memset(&(m_hevcIqMatrixParams->ucScalingListDCCoefSizeID3[0]),
+        0x10,
+        sizeof(m_hevcIqMatrixParams->ucScalingListDCCoefSizeID3));
+}
+
+void HevcBasicFeature::CreateDefaultScalingList()
+{
+    ENCODE_FUNC_CALL();
+
+    const uint8_t flatScalingList4x4[16] =
+    {
+        16,16,16,16,
+        16,16,16,16,
+        16,16,16,16,
+        16,16,16,16
+    };
+
+    const uint8_t defaultScalingList8x8[2][64] =
+    {
+        {
+            16,16,16,16,17,18,21,24,
+            16,16,16,16,17,19,22,25,
+            16,16,17,18,20,22,25,29,
+            16,16,18,21,24,27,31,36,
+            17,17,20,24,30,35,41,47,
+            18,19,22,27,35,44,54,65,
+            21,22,25,31,41,54,70,88,
+            24,25,29,36,47,65,88,115
+        },
+        {
+            16,16,16,16,17,18,20,24,
+            16,16,16,17,18,20,24,25,
+            16,16,17,18,20,24,25,28,
+            16,17,18,20,24,25,28,33,
+            17,18,20,24,25,28,33,41,
+            18,20,24,25,28,33,41,54,
+            20,24,25,28,33,41,54,71,
+            24,25,28,33,41,54,71,91
+        }
+    };
+
+    for (auto i = 0; i < 6; i++)
+    {
+        memcpy(&(m_hevcIqMatrixParams->ucScalingLists0[i][0]),
+            flatScalingList4x4,
+            sizeof(m_hevcIqMatrixParams->ucScalingLists0[i]));
+    }
+
+    for (auto i = 0; i < 3; i++)
+    {
+        memcpy(&(m_hevcIqMatrixParams->ucScalingLists1[i][0]),
+            defaultScalingList8x8[0],
+            sizeof(m_hevcIqMatrixParams->ucScalingLists1[i]));
+
+        memcpy(&(m_hevcIqMatrixParams->ucScalingLists1[3 + i][0]),
+            defaultScalingList8x8[1],
+            sizeof(m_hevcIqMatrixParams->ucScalingLists1[3 + i]));
+
+        memcpy(&(m_hevcIqMatrixParams->ucScalingLists2[i][0]),
+            defaultScalingList8x8[0],
+            sizeof(m_hevcIqMatrixParams->ucScalingLists2[i]));
+
+        memcpy(&(m_hevcIqMatrixParams->ucScalingLists2[3 + i][0]),
+            defaultScalingList8x8[1],
+            sizeof(m_hevcIqMatrixParams->ucScalingLists2[3 + i]));
+    }
+
+    memcpy(&(m_hevcIqMatrixParams->ucScalingLists3[0][0]),
+        defaultScalingList8x8[0],
+        sizeof(m_hevcIqMatrixParams->ucScalingLists3[0]));
+
+    memcpy(&(m_hevcIqMatrixParams->ucScalingLists3[1][0]),
+        defaultScalingList8x8[1],
+        sizeof(m_hevcIqMatrixParams->ucScalingLists3[1]));
+
+    memset(&(m_hevcIqMatrixParams->ucScalingListDCCoefSizeID2[0]),
+        0x10,
+        sizeof(m_hevcIqMatrixParams->ucScalingListDCCoefSizeID2));
+
+    memset(&(m_hevcIqMatrixParams->ucScalingListDCCoefSizeID3[0]),
+        0x10,
+        sizeof(m_hevcIqMatrixParams->ucScalingListDCCoefSizeID3));
+}
+
+
 MOS_STATUS HevcBasicFeature::SetPictureStructs()
 {
     MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
@@ -283,12 +394,13 @@ MOS_STATUS HevcBasicFeature::SetPictureStructs()
         return MOS_STATUS_INVALID_PARAMETER;
     }
 
-    if (!m_hevcSeqParams->scaling_list_enable_flag)
+    if (m_hevcSeqParams->scaling_list_enable_flag && !m_hevcPicParams->scaling_list_data_present_flag)
     {
-        //Create flat scaling list
-        memset(m_hevcIqMatrixParams,
-            0x10,
-            sizeof(*m_hevcIqMatrixParams));
+        CreateDefaultScalingList();
+    }
+    else if (!m_hevcSeqParams->scaling_list_enable_flag)
+    {
+        CreateFlatScalingList();
     }
 
     ENCODE_CHK_STATUS_RETURN(CalcLCUMaxCodingSize());
@@ -356,12 +468,10 @@ MOS_STATUS HevcBasicFeature::UpdateTrackedBufferParameters()
         ENCODE_CHK_STATUS_RETURN(m_trackedBuf->RegisterParam(encode::BufferType::mvTemporalBuffer, allocParams));
     }
 
-#ifdef _ENCODE_RESERVED
-    if (m_rsvdState && m_rsvdState->GetFeatureRsvdFlag())
+    if (m_422State && m_422State->GetFeature422Flag())
     {
-        ENCODE_CHK_STATUS_RETURN(m_rsvdState->RegisterMbCodeBuffer(m_trackedBuf, m_isMbCodeRegistered, m_mbCodeSize));
+        ENCODE_CHK_STATUS_RETURN(m_422State->RegisterMbCodeBuffer(m_trackedBuf, m_isMbCodeRegistered, m_mbCodeSize));
     }
-#endif
 
     ENCODE_CHK_STATUS_RETURN(EncodeBasicFeature::UpdateTrackedBufferParameters());
 
@@ -565,7 +675,7 @@ MOS_STATUS HevcBasicFeature::GetRecycleBuffers()
         }
     }
 
-    if (recycleBufferIdx == -1 || recycleBufferIdx >= m_maxSyncDepth)
+    if (recycleBufferIdx == -1)
     {
         return MOS_STATUS_SUCCESS;
     }
@@ -651,25 +761,23 @@ MOS_STATUS HevcBasicFeature::SetRoundingValues()
     return eStatus;
 }
 
-#ifdef _ENCODE_RESERVED
-MOS_STATUS HevcBasicFeature::InitRsvdState()
+MOS_STATUS HevcBasicFeature::Init422State()
 {
     ENCODE_FUNC_CALL();
 
-    m_rsvdState = MOS_New(HevcBasicFeatureRsvd);
-    ENCODE_CHK_NULL_RETURN(m_rsvdState);
+    m_422State = MOS_New(HevcBasicFeature422);
+    ENCODE_CHK_NULL_RETURN(m_422State);
 
     return MOS_STATUS_SUCCESS;
 }
-#endif
 
 MOS_STATUS HevcBasicFeature::GetSurfaceMmcInfo(PMOS_SURFACE surface, MOS_MEMCOMP_STATE &mmcState, uint32_t &compressionFormat) const
 {
     ENCODE_FUNC_CALL();
 
     ENCODE_CHK_NULL_RETURN(surface);
-    ENCODE_CHK_NULL_RETURN(m_mmcState);
 
+    ENCODE_CHK_NULL_RETURN(m_mmcState);
     if (m_mmcState->IsMmcEnabled())
     {
         ENCODE_CHK_STATUS_RETURN(m_mmcState->GetSurfaceMmcState(surface, &mmcState));
@@ -685,11 +793,15 @@ MOS_STATUS HevcBasicFeature::GetSurfaceMmcInfo(PMOS_SURFACE surface, MOS_MEMCOMP
 
 MHW_SETPAR_DECL_SRC(VDENC_PIPE_MODE_SELECT, HevcBasicFeature)
 {
+    ENCODE_FUNC_CALL();
     params.frameStatisticsStreamOut              = m_hevcPicParams->StatusReportEnable.fields.FrameStats;
     params.bitDepthMinus8                        = m_hevcSeqParams->bit_depth_luma_minus8;
     params.chromaType                            = m_hevcSeqParams->chroma_format_idc;
     params.wirelessSessionId                     = 0;
     params.randomAccess                          = !m_ref.IsLowDelay();
+    params.bt2020RGB2YUV                         = m_hevcSeqParams->InputColorSpace == ECOLORSPACE_P2020;
+    params.rgbInputStudioRange                   = params.bt2020RGB2YUV ? m_hevcSeqParams->RGBInputStudioRange : 0;
+    params.convertedYUVStudioRange               = params.bt2020RGB2YUV ? m_hevcSeqParams->ConvertedYUVStudioRange : 0;
 
     if (m_captureModeEnable)
     {
@@ -708,6 +820,7 @@ MHW_SETPAR_DECL_SRC(VDENC_PIPE_MODE_SELECT, HevcBasicFeature)
 
 MHW_SETPAR_DECL_SRC(VDENC_SRC_SURFACE_STATE, HevcBasicFeature)
 {
+    ENCODE_FUNC_CALL();
     params.pitch                = m_rawSurfaceToPak->dwPitch;
     params.tileType             = m_rawSurfaceToPak->TileType;
     params.tileModeGmm          = m_rawSurfaceToPak->TileModeGMM;
@@ -753,6 +866,7 @@ static inline uint32_t GetHwTileType(MOS_TILE_TYPE tileType, MOS_TILE_MODE_GMM t
 
 MHW_SETPAR_DECL_SRC(VDENC_REF_SURFACE_STATE, HevcBasicFeature)
 {
+    ENCODE_FUNC_CALL();
     params.pitch       = m_reconSurface.dwPitch;
     params.tileType    = m_reconSurface.TileType;
     params.tileModeGmm = m_reconSurface.TileModeGMM;
@@ -788,6 +902,7 @@ MHW_SETPAR_DECL_SRC(VDENC_REF_SURFACE_STATE, HevcBasicFeature)
 
 MHW_SETPAR_DECL_SRC(VDENC_DS_REF_SURFACE_STATE, HevcBasicFeature)
 {
+    ENCODE_FUNC_CALL();
     params.pitchStage1       = m_8xDSSurface->dwPitch;
     params.tileTypeStage1    = m_8xDSSurface->TileType;
     params.tileModeGmmStage1 = m_8xDSSurface->TileModeGMM;
@@ -811,6 +926,8 @@ MHW_SETPAR_DECL_SRC(VDENC_DS_REF_SURFACE_STATE, HevcBasicFeature)
 
 MHW_SETPAR_DECL_SRC(VDENC_PIPE_BUF_ADDR_STATE, HevcBasicFeature)
 {
+    ENCODE_FUNC_CALL();
+    ENCODE_CHK_NULL_RETURN(m_mmcState);   
     if (m_mmcState->IsMmcEnabled())
     {
         params.mmcEnabled = true;
@@ -867,6 +984,7 @@ MHW_SETPAR_DECL_SRC(VDENC_PIPE_BUF_ADDR_STATE, HevcBasicFeature)
 
 MHW_SETPAR_DECL_SRC(VDENC_CMD1, HevcBasicFeature)
 {
+    ENCODE_FUNC_CALL();
     auto settings = static_cast<HevcVdencFeatureSettings *>(m_constSettings);
     ENCODE_CHK_NULL_RETURN(settings);
 
@@ -880,6 +998,7 @@ MHW_SETPAR_DECL_SRC(VDENC_CMD1, HevcBasicFeature)
 
 MHW_SETPAR_DECL_SRC(VDENC_CMD2, HevcBasicFeature)
 {
+    ENCODE_FUNC_CALL();
     params.width  = (m_hevcSeqParams->wFrameWidthInMinCbMinus1 + 1) << (m_hevcSeqParams->log2_min_coding_block_size_minus3 + 3);
     params.height = (m_hevcSeqParams->wFrameHeightInMinCbMinus1 + 1) << (m_hevcSeqParams->log2_min_coding_block_size_minus3 + 3);
 
@@ -1029,7 +1148,7 @@ MHW_SETPAR_DECL_SRC(VDENC_CMD2, HevcBasicFeature)
         params.frameIdxL1Ref0 = 0;
     }
 
-    ENCODE_CHK_COND_RETURN(m_SubPelMode < 0 || m_SubPelMode > 3, "Invalid subPelMode");
+    ENCODE_CHK_COND_RETURN(m_SubPelMode > 3, "Invalid subPelMode");
     params.subPelMode = m_bEnableSubPelMode ? m_SubPelMode : 3;
     auto settings = static_cast<HevcVdencFeatureSettings *>(m_constSettings);
     ENCODE_CHK_NULL_RETURN(settings);
@@ -1044,6 +1163,7 @@ MHW_SETPAR_DECL_SRC(VDENC_CMD2, HevcBasicFeature)
 
 MHW_SETPAR_DECL_SRC(HCP_PIC_STATE, HevcBasicFeature)
 {
+    ENCODE_FUNC_CALL();
     params.framewidthinmincbminus1         = m_hevcSeqParams->wFrameWidthInMinCbMinus1;
     params.frameheightinmincbminus1        = m_hevcSeqParams->wFrameHeightInMinCbMinus1;
     params.mincusize                       = m_hevcSeqParams->log2_min_coding_block_size_minus3;
@@ -1094,6 +1214,7 @@ MHW_SETPAR_DECL_SRC(HCP_PIC_STATE, HevcBasicFeature)
 
 MHW_SETPAR_DECL_SRC(HEVC_VP9_RDOQ_STATE, HevcBasicFeature)
 {
+    ENCODE_FUNC_CALL();
     uint8_t bitDepthLumaMinus8   = m_hevcSeqParams->bit_depth_luma_minus8;
     uint8_t bitDepthChromaMinus8 = m_hevcSeqParams->bit_depth_chroma_minus8;
     uint8_t codingType           = m_hevcPicParams->CodingType;
@@ -1208,7 +1329,6 @@ MHW_SETPAR_DECL_SRC(HEVC_VP9_RDOQ_STATE, HevcBasicFeature)
             lambdaDouble *= MOS_MAX(1.00, MOS_MIN(1.6, 1.0 + 0.6 / 12.0 * (qpTemp - 10.0)));
             lambdaDouble        = lambdaDouble * 16 + 0.5;
             lambda              = (uint32_t)floor(lambdaDouble);
-            lambdaDouble        = (lambdaDouble > 65535) ? 65535 : lambdaDouble;
             lambda              = CodecHal_Clip3(0, 0xffff, lambda);
             params.lambdaTab[1][0][qp] = (uint16_t)lambda;
         }
@@ -1219,7 +1339,6 @@ MHW_SETPAR_DECL_SRC(HEVC_VP9_RDOQ_STATE, HevcBasicFeature)
             lambdaDouble *= MOS_MAX(0.95, MOS_MIN(1.20, 0.25 / 12.0 * (qpTemp - 10.0) + 0.95));
             lambdaDouble        = lambdaDouble * 16 + 0.5;
             lambda              = (uint32_t)floor(lambdaDouble);
-            lambdaDouble        = (lambdaDouble > 65535) ? 65535 : lambdaDouble;
             lambda              = CodecHal_Clip3(0, 0xffff, lambda);
             params.lambdaTab[1][1][qp] = (uint16_t)lambda;
         }
@@ -1235,6 +1354,7 @@ MHW_SETPAR_DECL_SRC(HEVC_VP9_RDOQ_STATE, HevcBasicFeature)
 
 MHW_SETPAR_DECL_SRC(HCP_SURFACE_STATE, HevcBasicFeature)
 {
+    ENCODE_FUNC_CALL();
     PMOS_SURFACE psSurface            = nullptr;
     uint8_t      ucBitDepthLumaMinus8 = 0;
     uint8_t      chromaType           = 0;
@@ -1256,13 +1376,12 @@ MHW_SETPAR_DECL_SRC(HCP_SURFACE_STATE, HevcBasicFeature)
         reconSurfHeight = m_rawSurfaceToPak->dwHeight;
         break;
     }
-#ifdef _MMC_SUPPORTED
+
     GetSurfaceMmcInfo(psSurface, params.mmcState, params.dwCompressionFormat);
     if (params.surfaceStateId == CODECHAL_HCP_REF_SURFACE_ID)
     {
         m_ref.MHW_SETPAR_F(HCP_SURFACE_STATE)(params);
     }
-#endif
 
     ENCODE_CHK_NULL_RETURN(psSurface);
     params.surfacePitchMinus1 = psSurface->dwPitch - 1;
@@ -1357,7 +1476,7 @@ MHW_SETPAR_DECL_SRC(HCP_SURFACE_STATE, HevcBasicFeature)
     else if (params.surfaceFormat == hcp::SURFACE_FORMAT::SURFACE_FORMAT_Y216VARIANT ||
              params.surfaceFormat == hcp::SURFACE_FORMAT::SURFACE_FORMAT_YUY2VARIANT)
     {
-        params.yOffsetForUCbInPixel = params.yOffsetForVCr = (uint16_t)reconSurfHeight;
+        params.yOffsetForUCbInPixel = params.yOffsetForVCr = MOS_ALIGN_CEIL((uint16_t)reconSurfHeight, 8);
     }
 
     return MOS_STATUS_SUCCESS;
@@ -1365,6 +1484,7 @@ MHW_SETPAR_DECL_SRC(HCP_SURFACE_STATE, HevcBasicFeature)
 
 MHW_SETPAR_DECL_SRC(HCP_SLICE_STATE, HevcBasicFeature)
 {
+    ENCODE_FUNC_CALL();
     ENCODE_CHK_NULL_RETURN(m_hevcSliceParams);
     PCODEC_HEVC_ENCODE_SLICE_PARAMS pEncodeHevcSliceParams = (CODEC_HEVC_ENCODE_SLICE_PARAMS *) &m_hevcSliceParams[m_curNumSlices];
     uint32_t ctbSize    = 1 << (m_hevcSeqParams->log2_max_coding_block_size_minus3 + 3);
