@@ -379,6 +379,7 @@ bool SwFilterDnHandler::IsFeatureEnabled(VP_PIPELINE_PARAMS& params, bool isInpu
 
     if (SwFilterFeatureHandler::IsVeboxTypeHMode())
     {
+        VP_PUBLIC_WARNINGMESSAGE("Disable DN for veboxTypeH.");
         return false;
     }
 
@@ -481,6 +482,7 @@ bool SwFilterDiHandler::IsFeatureEnabled(VP_PIPELINE_PARAMS& params, bool isInpu
 
     if (SwFilterFeatureHandler::IsVeboxTypeHMode())
     {
+        VP_PUBLIC_WARNINGMESSAGE("Disable Di for veboxTypeH.");
         return false;
     }
 
@@ -556,6 +558,7 @@ bool SwFilterSteHandler::IsFeatureEnabled(VP_PIPELINE_PARAMS& params, bool isInp
 
     if (SwFilterFeatureHandler::IsVeboxTypeHMode())
     {
+        VP_PUBLIC_WARNINGMESSAGE("Disable Ste for veboxTypeH.");
         return false;
     }
 
@@ -616,6 +619,7 @@ bool SwFilterTccHandler::IsFeatureEnabled(VP_PIPELINE_PARAMS& params, bool isInp
 
     if (SwFilterFeatureHandler::IsVeboxTypeHMode())
     {
+        VP_PUBLIC_WARNINGMESSAGE("Disable Tcc for veboxTypeH.");
         return false;
     }
 
@@ -782,21 +786,27 @@ bool SwFilterHdrHandler::IsFeatureEnabled(VP_PIPELINE_PARAMS &params, bool isInp
         // Check if input/output gamma is same(TBD)
         // Check if input/output color space is same
         bool bColorSpaceConversion = true;
+
         if (IS_COLOR_SPACE_BT2020(pRenderTarget->ColorSpace) &&
             IS_COLOR_SPACE_BT2020(pSrc->ColorSpace))
         {
             bColorSpaceConversion = false;
         }
-        if ((pRenderTarget->ColorSpace == CSpace_sRGB || pRenderTarget->ColorSpace == CSpace_stRGB) &&
-            (pSrc->ColorSpace == CSpace_BT709 || pSrc->ColorSpace == CSpace_BT709_FullRange))
+        else if ((pRenderTarget->ColorSpace == CSpace_sRGB || pRenderTarget->ColorSpace == CSpace_stRGB) &&
+                (pSrc->ColorSpace == CSpace_BT709 || pSrc->ColorSpace == CSpace_BT709_FullRange))
         {
             bColorSpaceConversion = false;
         }
-        if ((pRenderTarget->ColorSpace == CSpace_sRGB || pRenderTarget->ColorSpace == CSpace_stRGB) &&
+        else if ((pRenderTarget->ColorSpace == CSpace_sRGB || pRenderTarget->ColorSpace == CSpace_stRGB) &&
             (pSrc->ColorSpace == CSpace_BT601 || pSrc->ColorSpace == CSpace_BT601_FullRange))
         {
             bColorSpaceConversion = false;
         }
+        else if (IS_RGB32_FORMAT(pSrc->Format))
+        {
+            bColorSpaceConversion = false;
+            // HDR pipe cannot be used for ARGB8 input.
+        }
         bFP16HdrProcessing = bColorSpaceConversion;
     }
 
@@ -1075,6 +1085,7 @@ bool SwFilterCgcHandler::IsFeatureEnabled(VP_PIPELINE_PARAMS& params, bool isInp
 
     if (SwFilterFeatureHandler::IsVeboxTypeHMode())
     {
+        VP_PUBLIC_WARNINGMESSAGE("Disable Cgc for veboxTypeH.");
         return false;
     }
 
