@@ -34,7 +34,13 @@ VpUserFeatureControl::VpUserFeatureControl(MOS_INTERFACE &osInterface, VpPlatfor
 {
     MOS_STATUS status = MOS_STATUS_SUCCESS;
     uint32_t compBypassMode = VPHAL_COMP_BYPASS_ENABLED;    // Vebox Comp Bypass is on by default
-    auto skuTable = m_osInterface->pfnGetSkuTable(m_osInterface);
+    MEDIA_FEATURE_TABLE* skuTable = nullptr;
+
+    if (m_osInterface->pfnGetSkuTable)
+    {
+        skuTable = m_osInterface->pfnGetSkuTable(m_osInterface);
+    }
+
 
     m_userSettingPtr = m_osInterface->pfnGetUserSettingInstance(m_osInterface);
     // Read user feature key to get the Composition Bypass mode
@@ -232,6 +238,7 @@ VpUserFeatureControl::VpUserFeatureControl(MOS_INTERFACE &osInterface, VpPlatfor
     MT_LOG3(MT_VP_USERFEATURE_CTRL, MT_NORMAL, MT_VP_UF_CTRL_DISABLE_VEOUT, m_ctrlValDefault.disableVeboxOutput,
         MT_VP_UF_CTRL_DISABLE_SFC, m_ctrlValDefault.disableSfc, MT_VP_UF_CTRL_CCS, m_ctrlValDefault.computeContextEnabled);
 
+#if (_DEBUG || _RELEASE_INTERNAL)
     uint32_t globalLutMode = VPHAL_HDR_LUT_MODE_NONE;
     status                 = ReadUserSetting(
         m_userSettingPtr,
@@ -270,6 +277,7 @@ VpUserFeatureControl::VpUserFeatureControl(MOS_INTERFACE &osInterface, VpPlatfor
     {
         m_ctrlValDefault.disableAutoMode = disableAutoMode;
     }
+#endif
 
     uint32_t splitFramePortions = 1;
     status                      = ReadUserSetting(
@@ -284,6 +292,28 @@ VpUserFeatureControl::VpUserFeatureControl(MOS_INTERFACE &osInterface, VpPlatfor
         m_ctrlValDefault.splitFramePortions = splitFramePortions;
     }
 
+#if (_DEBUG || _RELEASE_INTERNAL)
+    std::string lut3DFilePath = "";
+    status = ReadUserSetting(
+        m_userSettingPtr,
+        lut3DFilePath,
+        __VPHAL_3DLUT_FILE_PATH,
+        MediaUserSetting::Group::Sequence,
+        std::string(""),  // Default empty string
+        true);  // Use custom value
+    if (MOS_SUCCEEDED(status) && !lut3DFilePath.empty())
+    {
+        m_ctrlValDefault.lut3DFilePath = lut3DFilePath;
+        m_ctrlValDefault.enable3DLutNewLayout = true;
+        VP_PUBLIC_NORMALMESSAGE("3DLUT new layout enabled with file: %s", lut3DFilePath.c_str());
+    }
+    else
+    {
+        m_ctrlValDefault.enable3DLutNewLayout = false;
+        m_ctrlValDefault.lut3DFilePath = "";
+    }
+#endif
+
     //check vebox type 
     if (skuTable && (MEDIA_IS_SKU(skuTable, FtrVeboxTypeH)))
     {
@@ -340,6 +370,22 @@ MOS_STATUS VpUserFeatureControl::CreateUserSettingForDebug()
         m_ctrlValDefault.force3DLutInterpolation = 0;
     }
 
+    uint32_t is3DLutKernelOnly = 0;
+    eRegKeyReadStatus                = ReadUserSettingForDebug(
+        m_userSettingPtr,
+        is3DLutKernelOnly,
+        __VPHAL_FORCE_VP_3DLUT_KERNEL_ONLY,
+        MediaUserSetting::Group::Sequence);
+    if (MOS_SUCCEEDED(eRegKeyReadStatus))
+    {
+        m_ctrlValDefault.is3DLutKernelOnly = is3DLutKernelOnly;
+    }
+    else
+    {
+        // Default value
+        m_ctrlValDefault.is3DLutKernelOnly = 0;
+    }
+
     //SFC NV12/P010 Linear Output.
     uint32_t enabledSFCNv12P010LinearOutput = 0;
     eRegKeyReadStatus = ReadUserSettingForDebug(
@@ -391,7 +437,131 @@ MOS_STATUS VpUserFeatureControl::CreateUserSettingForDebug()
         // Default value
         m_ctrlValDefault.enableIFNCC = false;
     }
+
+    bool bEnableOCL3DLut = false;
+    eRegKeyReadStatus   = ReadUserSettingForDebug(
+        m_userSettingPtr,
+        bEnableOCL3DLut,
+        __MEDIA_USER_FEATURE_VALUE_ENABLE_VP_OCL_3DLUT,
+        MediaUserSetting::Group::Sequence);
+    if (MOS_SUCCEEDED(eRegKeyReadStatus))
+    {
+        m_ctrlValDefault.enableOcl3DLut = bEnableOCL3DLut ? VP_CTRL_ENABLE : VP_CTRL_DISABLE;
+    }
+    else
+    {
+        // Default value
+        m_ctrlValDefault.enableOcl3DLut = VP_CTRL_DEFAULT;
+    }
+
+    bool bForceOclFC   = false;
+    eRegKeyReadStatus = ReadUserSettingForDebug(
+        m_userSettingPtr,
+        bForceOclFC,
+        __MEDIA_USER_FEATURE_VALUE_ENABLE_VP_OCL_FC,
+        MediaUserSetting::Group::Sequence);
+    if (MOS_SUCCEEDED(eRegKeyReadStatus))
+    {
+        m_ctrlValDefault.forceOclFC = bForceOclFC ? VP_CTRL_ENABLE : VP_CTRL_DISABLE;
+    }
+    else
+    {
+        // Default value
+        m_ctrlValDefault.forceOclFC = VP_CTRL_DEFAULT;
+    }
+
+    bool bDisableOclFcFp = false;
+    eRegKeyReadStatus   = ReadUserSettingForDebug(
+        m_userSettingPtr,
+        bDisableOclFcFp,
+        __MEDIA_USER_FEATURE_VALUE_DISABLE_VP_OCL_FC_FP,
+        MediaUserSetting::Group::Sequence);
+    if (MOS_SUCCEEDED(eRegKeyReadStatus))
+    {
+        m_ctrlValDefault.bDisableOclFcFp = bDisableOclFcFp;
+    }
+    else
+    {
+        // Default value
+        m_ctrlValDefault.bDisableOclFcFp = false;
+    }
 #endif
+#if (_DEBUG || _RELEASE_INTERNAL)
+    bool enableSFCLinearOutputByTileConvert = 0;
+    eRegKeyReadStatus   = ReadUserSettingForDebug(
+        m_userSettingPtr,
+        enableSFCLinearOutputByTileConvert,
+        __MEDIA_USER_FEATURE_VALUE_ENABLE_VESFC_LINEAR_OUTPUT_BY_TILECONVERT,
+        MediaUserSetting::Group::Device);
+    if (MOS_SUCCEEDED(eRegKeyReadStatus))
+    {
+        m_ctrlValDefault.enableSFCLinearOutputByTileConvert = enableSFCLinearOutputByTileConvert;
+    }
+    else
+#endif
+    {
+        if (m_osInterface->pfnGetWaTable)
+        {
+            auto waTable = m_osInterface->pfnGetWaTable(m_osInterface);
+            VP_PUBLIC_CHK_NULL_RETURN(waTable);
+            // Default value
+            m_ctrlValDefault.enableSFCLinearOutputByTileConvert = MEDIA_IS_WA(waTable, Wa_15016458807);
+        }
+    }
+    VP_PUBLIC_NORMALMESSAGE("enableSFCLinearOutputByTileConvert value is set as %d.", m_ctrlValDefault.enableSFCLinearOutputByTileConvert);
+
+#if (_DEBUG || _RELEASE_INTERNAL)
+    uint32_t fallbackScalingToRender8K = 0;
+    eRegKeyReadStatus                  = ReadUserSettingForDebug(
+        m_userSettingPtr,
+        fallbackScalingToRender8K,
+        __MEDIA_USER_FEATURE_VALUE_FALLBACK_SCALING_TO_RENDER_8K,
+        MediaUserSetting::Group::Sequence,
+        true,
+        true);
+    if (MOS_SUCCEEDED(eRegKeyReadStatus))
+    {
+        m_ctrlValDefault.fallbackScalingToRender8K = fallbackScalingToRender8K;
+    }
+    else
+#endif
+    {
+        // Do not set fallbackScalingToRender8K if render is disabled. This is for internal vesfc usage (e.g., 8k preenc) that should not fallback to render.
+        if (m_vpPlatformInterface && !m_vpPlatformInterface->IsRenderDisabled())
+        {
+            if (m_osInterface->pfnGetWaTable)
+            {
+                auto *waTable = m_osInterface->pfnGetWaTable(m_osInterface);
+                VP_PUBLIC_CHK_NULL_RETURN(waTable);
+                m_ctrlValDefault.fallbackScalingToRender8K = MEDIA_IS_WA(waTable, Wa_16025683853);
+            }
+        }
+    }
+    VP_PUBLIC_NORMALMESSAGE("fallbackScalingToRender8K %d", m_ctrlValDefault.fallbackScalingToRender8K);
+
+    return MOS_STATUS_SUCCESS;
+}
+
+MOS_STATUS VpUserFeatureControl::UpdateOnNewPipe(SwFilterPipe *swFilterPipe, uint32_t pipeCnt)
+{
+    VP_PUBLIC_CHK_NULL_RETURN(swFilterPipe);
+
+    // if more than one swFilterPipe, then update the swFilterPipe config
+    if (pipeCnt > 1)
+    {
+        if (swFilterPipe->IsForceToRender())
+        {
+            m_ctrlVal.disableSfc         = true;
+            m_ctrlVal.disableVeboxOutput = true;
+            VP_PUBLIC_NORMALMESSAGE("Disable SFC and vebox output as task is forced to render.");
+        }
+        else
+        {
+            m_ctrlVal.disableSfc         = false;
+            m_ctrlVal.disableVeboxOutput = false;
+        }
+    }
+
     return MOS_STATUS_SUCCESS;
 }
 
@@ -407,6 +577,10 @@ MOS_STATUS VpUserFeatureControl::Update(PVP_PIPELINE_PARAMS params)
         m_ctrlVal.disableVeboxOutput = true;
         VP_PUBLIC_NORMALMESSAGE("Disable SFC and vebox output as task is forced to render.");
     }
+    if (params->renderCommandStreamType == VPHAL_RENDER_COMMAND_STREAM_RCS)
+    {
+        m_ctrlVal.computeContextEnabled = false;
+    }
 
     return MOS_STATUS_SUCCESS;
 }
@@ -418,4 +592,43 @@ PMOS_OCA_LOG_USER_FEATURE_CONTROL_INFO VpUserFeatureControl::GetOcaFeautreContro
         m_pOcaFeatureControlInfo = (PMOS_OCA_LOG_USER_FEATURE_CONTROL_INFO)MOS_AllocAndZeroMemory(sizeof(MOS_OCA_LOG_USER_FEATURE_CONTROL_INFO));
     }
     return m_pOcaFeatureControlInfo;
-}
\ No newline at end of file
+}
+
+
+bool VpUserFeatureControl::EnableOclFC()
+{
+    bool bEnableOclFC = false;
+    if (m_ctrlVal.forceOclFC == VP_CTRL_ENABLE)
+    {
+        bEnableOclFC = true;
+    }
+    else if (m_ctrlVal.forceOclFC == VP_CTRL_DISABLE)
+    {
+        bEnableOclFC = false;
+    }
+    else // if (m_ctrlVal.forceOclFC == VP_CTRL_DEFAULT)
+    {
+        bEnableOclFC = (m_vpPlatformInterface && m_vpPlatformInterface->IsOclKernelEnabled());
+    }
+    VP_PUBLIC_NORMALMESSAGE("EnableOclFC set as %d", bEnableOclFC);
+    return bEnableOclFC;
+}
+
+bool VpUserFeatureControl::EnableOcl3DLut()
+{
+    bool bEnableOcl3DLut = false;
+    if (m_ctrlVal.enableOcl3DLut == VP_CTRL_ENABLE)
+    {
+        bEnableOcl3DLut = true;
+    }
+    else if (m_ctrlVal.enableOcl3DLut == VP_CTRL_DISABLE)
+    {
+        bEnableOcl3DLut = false;
+    }
+    else // if (m_ctrlVal.enableOcl3DLut == VP_CTRL_DEFAULT)
+    {
+        bEnableOcl3DLut = (m_vpPlatformInterface && m_vpPlatformInterface->IsOclKernelEnabled());
+    }
+    VP_PUBLIC_NORMALMESSAGE("EnableOcl3DLut set as %d", bEnableOcl3DLut);
+    return bEnableOcl3DLut;
+}
