@@ -358,6 +358,7 @@ struct mos_bufmgr {
     void (*disable_object_capture)(struct mos_bufmgr *bufmgr) = nullptr;
     int (*get_memory_info)(struct mos_bufmgr *bufmgr, char *info, uint32_t length) = nullptr;
     int (*get_devid)(struct mos_bufmgr *bufmgr) = nullptr;
+    void (*realloc_cache)(struct mos_bufmgr *bufmgr, uint8_t alloc_mode) = nullptr;
     int (*query_engines_count)(struct mos_bufmgr *bufmgr,
                           unsigned int *nengine) = nullptr;
     
@@ -369,6 +370,11 @@ struct mos_bufmgr {
 
     size_t (*get_engine_class_size)() = nullptr;
 
+    void (*select_fixed_engine)(struct mos_bufmgr *bufmgr,
+            void *engine_map,
+            uint32_t *nengine,
+            uint32_t fixed_instance_mask) = nullptr;
+
     int (*set_context_param)(struct mos_linux_context *ctx,
                     uint32_t size,
                     uint64_t param,
@@ -388,7 +394,7 @@ struct mos_bufmgr {
                                uint64_t param,
                                uint64_t *value) = nullptr;
     struct mos_linux_bo *(*bo_create_from_prime)(struct mos_bufmgr *bufmgr,
-                            int prime_fd, int size) = nullptr;
+                            struct mos_drm_bo_alloc_prime *alloc_prime) = nullptr;
     int (*bo_export_to_prime)(struct mos_linux_bo *bo, int *prime_fd) = nullptr;
     int (*reg_read)(struct mos_bufmgr *bufmgr,
                    uint32_t offset,
